@@ -183,6 +183,7 @@ module TZInfo
         c.timezone 'America/Cambridge_Bay', 24881, 360, -37819, 360, 'Mountain Time - west Nunavut'
         c.timezone 'America/Yellowknife', 1249, 20, -2287, 20, 'Mountain Time - central Northwest Territories'
         c.timezone 'America/Inuvik', 246059, 3600, -8023, 60, 'Mountain Time - west Northwest Territories'
+        c.timezone 'America/Creston', 491, 10, -6991, 60, 'Mountain Standard Time - Creston, British Columbia'
         c.timezone 'America/Dawson_Creek', 1793, 30, -3607, 30, 'Mountain Standard Time - Dawson Creek & Fort Saint John, British Columbia'
         c.timezone 'America/Vancouver', 739, 15, -7387, 60, 'Pacific Time - west British Columbia'
         c.timezone 'America/Whitehorse', 3643, 60, -2701, 20, 'Pacific Time - south Yukon'
@@ -690,7 +691,7 @@ module TZInfo
         c.timezone 'Europe/Kaliningrad', 3283, 60, 41, 2, 'Moscow-01 - Kaliningrad'
         c.timezone 'Europe/Moscow', 223, 4, 451, 12, 'Moscow+00 - west Russia'
         c.timezone 'Europe/Volgograd', 731, 15, 533, 12, 'Moscow+00 - Caspian Sea'
-        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow - Samara, Udmurtia'
+        c.timezone 'Europe/Samara', 266, 5, 1003, 20, 'Moscow+00 - Samara, Udmurtia'
         c.timezone 'Asia/Yekaterinburg', 1137, 20, 303, 5, 'Moscow+02 - Urals'
         c.timezone 'Asia/Omsk', 55, 1, 367, 5, 'Moscow+03 - west Siberia'
         c.timezone 'Asia/Novosibirsk', 1651, 30, 995, 12, 'Moscow+03 - Novosibirsk'
